# vim: set sw=4 ts=4 et nu:

# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/

Name:               rtaudio
Version:            4.0.10
%define soname      4
Release:            3.9
Summary:            Realtime Audio Input/Output Library
Source:             http://www.music.mcgill.ca/~gary/rtaudio/release/rtaudio-%{version}.tar.gz
Patch1:             rtaudio-optflags.patch
Patch2:             rtaudio-fix_version.patch
Patch3:             rtaudio-keep_your_compiler_flags_for_yourself.patch
Source98:           baselibs.conf
URL:                http://www.music.mcgill.ca/~gary/rtaudio/
Group:              System/Libraries
License:            MIT
BuildRoot:          %{_tmppath}/build-%{name}-%{version}
BuildRequires:      jack-devel
BuildRequires:      alsa-devel
BuildRequires:      gcc-c++ make pkgconfig
BuildRequires:      autoconf automake libtool
BuildRequires:      python-devel

%description
RtAudio is a set of C++ classes that provides a common API (Application
Programming Interface) for realtime audio input/output across Linux (native
ALSA, JACK, and OSS), Macintosh OS X, SGI, and Windows (DirectSound and ASIO)
operating systems.
RtAudio significantly simplifies the process of interacting with computer audio
hardware.

It was designed with the following objectives:
- object-oriented C++ design
- simple, common API across all supported platforms
- only one source and two header files for easy inclusion in programming
  projects
- allow simultaneous multi-api support
- support dynamic connection of devices
- provide extensive audio device parameter control
- allow audio device capability probing
- automatic internal conversion for data format, channel number compensation,
  (de)interleaving, and byte-swapping

RtAudio incorporates the concept of audio streams, which represent audio output
(playback) and/or input (recording).  Available audio devices and their
capabilities can be enumerated and then specified when opening a stream.  Where
applicable, multiple API support can be compiled and a particular API specified
when creating an RtAudio instance.

%package -n librtaudio%{soname}
Summary:            Realtime Audio Input/Output Library
Group:              System/Libraries

%description -n librtaudio%{soname}
RtAudio is a set of C++ classes that provides a common API (Application
Programming Interface) for realtime audio input/output across Linux (native
ALSA, JACK, and OSS), Macintosh OS X, SGI, and Windows (DirectSound and ASIO)
operating systems.
RtAudio significantly simplifies the process of interacting with computer audio
hardware.

It was designed with the following objectives:
- object-oriented C++ design
- simple, common API across all supported platforms
- only one source and two header files for easy inclusion in programming
  projects
- allow simultaneous multi-api support
- support dynamic connection of devices
- provide extensive audio device parameter control
- allow audio device capability probing
- automatic internal conversion for data format, channel number compensation,
  (de)interleaving, and byte-swapping

RtAudio incorporates the concept of audio streams, which represent audio output
(playback) and/or input (recording).  Available audio devices and their
capabilities can be enumerated and then specified when opening a stream.  Where
applicable, multiple API support can be compiled and a particular API specified
when creating an RtAudio instance.

%package devel
Summary:            Realtime Audio Input/Output Library
Group:              Development/Libraries/C and C++
Requires:           librtaudio%{soname} = %{version}

%description devel
RtAudio is a set of C++ classes that provides a common API (Application
Programming Interface) for realtime audio input/output across Linux (native
ALSA, JACK, and OSS), Macintosh OS X, SGI, and Windows (DirectSound and ASIO)
operating systems.
RtAudio significantly simplifies the process of interacting with computer audio
hardware.

It was designed with the following objectives:
- object-oriented C++ design
- simple, common API across all supported platforms
- only one source and two header files for easy inclusion in programming
  projects
- allow simultaneous multi-api support
- support dynamic connection of devices
- provide extensive audio device parameter control
- allow audio device capability probing
- automatic internal conversion for data format, channel number compensation,
  (de)interleaving, and byte-swapping

RtAudio incorporates the concept of audio streams, which represent audio output
(playback) and/or input (recording).  Available audio devices and their
capabilities can be enumerated and then specified when opening a stream.  Where
applicable, multiple API support can be compiled and a particular API specified
when creating an RtAudio instance.

%package devel-static
Summary:            Realtime Audio Input/Output Library
Group:              Development/Libraries/C and C++
Requires:           %{name}-devel = %{version}

%description devel-static
This package contains the static library of %{name}.

%package -n python-rtaudio
Summary:            Realtime Audio Input/Output Library for Python
Group:              Development/Libraries/Python
# does _NOT_ require the shlib package

%description -n python-rtaudio
RtAudio is a set of C++ classes that provides a common API (Application
Programming Interface) for realtime audio input/output across Linux (native
ALSA, JACK, and OSS), Macintosh OS X, SGI, and Windows (DirectSound and ASIO)
operating systems.
RtAudio significantly simplifies the process of interacting with computer audio
hardware.

This package provides Python bindings to rtaudio.

%prep
%setup -q
%patch1
%patch2
%patch3

%build
%configure \
    --with-jack \
    --with-alsa \
    --with-oss \
    CC="%__cxx" \
    CXXFLAGS="%{optflags}"

# don't parallelize, breaks build
%__make OPTFLAGS="%{optflags}"

B="$PWD"
pushd "contrib/python/pyrtaudio"
CFLAGS="-I$B/include -fno-strict-aliasing" \
%__python ./setup.py build
popd

%install
# there is no make install
%__install -d "%{buildroot}%{_includedir}"
%__install -m0644 *.h "%{buildroot}%{_includedir}/"
%__install -d "%{buildroot}%{_libdir}"
%__install -m0755 librtaudio.so.%{soname}.* "%{buildroot}%{_libdir}/"
pushd "%{buildroot}%{_libdir}"
%__ln_s librtaudio.so.%{soname}.* librtaudio.so.%{soname}
%__ln_s librtaudio.so.%{soname}.* librtaudio.so
popd
%__install -m0644 librtaudio.a "%{buildroot}%{_libdir}/"
%__install -D -m0755 rtaudio-config "%{buildroot}%{_bindir}/rtaudio-config"

B="$PWD"
pushd "contrib/python/pyrtaudio"
%__python ./setup.py install \
    --root="%{buildroot}" \
    --prefix="%{_prefix}" \
    --record-rpm="$B/.pyfiles.lst"
popd

%post   -n librtaudio%{soname} -p /sbin/ldconfig
%postun -n librtaudio%{soname} -p /sbin/ldconfig

%clean
%{?buildroot:%__rm -rf "%{buildroot}"}

%files -n librtaudio%{soname}
%defattr(-,root,root)
%doc readme
%{_libdir}/librtaudio.so.%{soname}
%{_libdir}/librtaudio.so.%{version}

%files devel
%defattr(-,root,root)
%{_bindir}/rtaudio-config
%{_includedir}/*.h
%{_libdir}/librtaudio.so

%files devel-static
%defattr(-,root,root)
%{_libdir}/librtaudio.a

%files -n python-rtaudio -f .pyfiles.lst
%defattr(-,root,root)

%changelog
* Sat Apr 21 2012 pascal.bleser@opensuse.org
- initial version (4.0.10)
